Name:          ognl
Version:       3.0.2
Release:       %mkrel 1
Summary:       Object-Graph Navigation Language
Group:         Development/Java
License:       BSD
URL:           http://www.opensymphony.com/ognl/
# git clone git://github.com/jkuhnert/ognl.git
# cd ognl && git archive --format=tar --prefix=ognl-3.0.2/ master | xz > ../ognl-3.0.2-src-git.tar.xz
Source0:       ognl-%{version}-src-git.tar.xz
Source1:       ognl-%{version}-osbuild.xml
Patch0:        ognl-2.7.3-build_xml.patch
Patch1:        ognl-2.7.3-docbook_xml_source_compliance.patch

BuildRequires: java-devel
BuildRequires: jpackage-utils

BuildRequires: ant
BuildRequires: ant-contrib
BuildRequires: ant-junit
BuildRequires: ant-nodeps
BuildRequires: ant-trax
BuildRequires: docbook-dtds
BuildRequires: docbook-style-xsl
BuildRequires: easymock2
BuildRequires: fop >= 0.95-11
BuildRequires: javacc
BuildRequires: javassist
BuildRequires: junit4
#BuildRequires: mvel1 >= 1.2.0pre0
BuildRequires: objectweb-asm
BuildRequires: testng
BuildRequires: xalan-j2
BuildRequires: xml-commons-apis

Requires:      easymock2
Requires:      javassist

Requires:      jpackage-utils
Requires(post): jpackage-utils
Requires(postun): jpackage-utils
Requires:      java
BuildArch:     noarch


%description
OGNL stands for Object-Graph Navigation Language; it is an
expression language for getting and setting properties of
Java objects. You use the same expression for both getting
and setting the value of a property.
The ognl.Ognl class contains convenience methods for evaluating
OGNL expressions. You can do this in two stages, parsing an
expression into an internal form and then using that internal
form to either set or get the value of a property; or you can
do it in a single stage, and get or set a property using the
String form of the expression directly.
Many people have asked exactly what OGNL is good for. Several
of the uses to which OGNL has been applied are:
* A binding language between GUI elements (textfield, combobox,
 etc.) to model objects. Transformations are made easier by
 OGNL's TypeConverter mechanism to convert values from one
 type to another (String to numeric types, for example).
* A data source language to map between table columns and a
 TableModel.
* A binding language between web components and the underlying
 model objects (WebOGNL, Tapestry and WebWork).
* A more expressive replacement for the property-getting
 language used by the Jakarta Commons BeanUtils package
 (which only allows simple property navigation and
 rudimentary indexed properties).
Most of what you can do in Java is possible in OGNL, plus other
extras such as list projection and selection and lambda expressions.

%package javadoc
Group:         Development/Java
Summary:       Javadoc for %{name}

%description javadoc
Object-Graph Navigation Language.

This package contains javadoc for %{name}.

%package manual
Group:         Development/Java
Summary:       Manual for %{name}

%description manual
Object-Graph Navigation Language.

This package contains manual for %{name}.

%prep

%setup -q -n %{name}-%{version}

for j in $(find . -name "*.jar"); do
  mv $j ${j}.no
done

cat > build.properties << GIL
name = %{name}
fullname = OGNL
version = %{version}
cvs.tag = %{name}_$(echo %version | tr . _)
package = %{name}
GIL

cat > docbook.properties << GIL
docbook.xsl.base
docbook.xsl.path=`rpm -ql docbook-style-xsl | grep /html/chunk.xsl | sed 's|/html/chunk.xsl||'`/
docbook.xml.path=%{_datadir}/sgml/docbook/xml-dtd-4.5
fop.path=%{_javadir}/
GIL



cp %{SOURCE1} osbuild.xml

pushd lib
  ln -sf $(build-classpath javacc) javacc.jar
  ln -sf $(build-classpath javassist) javassist.jar
  ln -sf $(build-classpath junit) junit.jar
  ln -sf $(build-classpath ant/ant-contrib) ant-contrib-0.3.jar
  ln -sf $(build-classpath easymock2) easymock-2.0.jar
  ln -sf $(build-classpath objectweb-asm/asm-all) asm.jar
  ln -sf $(build-classpath testng) testng-5.1-jdk15.jar
#  ln -sf $(build-classpath mvel1)
popd

%patch0 -p1
%patch1 -p1

%build

export CLASSPATH=""
CLASSPATH=$CLASSPATH:$(build-classpath javassist xalan-j2 xml-commons-apis xalan-j2-serializer)
CLASSPATH=$CLASSPATH:$(build-classpath ant/ant-contrib fop javacc javassist junit4)
CLASSPATH=$CLASSPATH:$(build-classpath ant/ant-junit ant/ant-nodeps ant/ant-trax)
ant javacc-generate jar docs.impl javadocs

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

mkdir -p %{buildroot}%{_javadir}


install -m 0644 build/ognl-%{version}.jar \
  %{buildroot}%{_javadir}/ognl-%{version}.jar

(
  cd %{buildroot}%{_javadir}
  for jar in *-%{version}.jar; do
    ln -sf ${jar} `echo $jar| sed "s|-%{version}||g"`
  done
)

mkdir -p %{buildroot}%{_mavenpomdir}
install -m 644 pom.xml %{buildroot}%{_mavenpomdir}/JPP-ognl.pom
%add_to_maven_depmap ognl ognl %{version} JPP ognl

mkdir -p %{buildroot}%{_javadocdir}/ognl
cp -pr dist/docs/api/* %{buildroot}%{_javadocdir}/ognl
rm -rf dist/docs/api

mkdir -p %{buildroot}%{_docdir}/ognl
cp -p LICENSE.txt %{buildroot}%{_docdir}/ognl
cp -pr dist/docs/* %{buildroot}%{_docdir}/ognl

(
  cd %{buildroot}%{_docdir}/ognl
  ln -s %{_javadocdir}/ognl api
)

%post
%update_maven_depmap

%postun
%update_maven_depmap

%files
%{_javadir}/ognl-%{version}.jar
%{_javadir}/ognl.jar
%{_mavenpomdir}/*
%{_mavendepmapfragdir}/*
%{_docdir}/ognl/LICENSE.txt

%files javadoc
%{_javadocdir}/ognl
%{_docdir}/ognl/api

%files manual
%{_docdir}/ognl/html/*
%{_docdir}/ognl/index.html
%{_docdir}/ognl/pdf/*


%changelog

* Fri Nov 11 2011 dmorgan <dmorgan> 3.0.2-1.mga2
+ Revision: 166623
+ rebuild (emptylog)

* Mon Sep 26 2011 gil <gil> 3.0.2-0.mga2
+ Revision: 148811
- update to 3.0.2
- added new sub package manual
- update to 2.7.3
- imported package ognl

  + dmorgan <dmorgan>
    - Clean spec file


* Mon Jun 06 2011 gil <gil> 2.6.9-0.%%mkrel
- initial rpm